if not LibStub then error("RaidEquipCompare requires LibStub.") end
local lre = LibStub("LibRaidEquip-1.0", true)
if not lre then error("RaidEquipCompare requires LibRaidEquip-1.0.") end

local frame = CreateFrame("Frame", nil, UIParent)

local equipLocToSlotId = {
	["INVTYPE_AMMO"] 				= 0,
	["INVTYPE_HEAD"] 				= 1,
	["INVTYPE_NECK"]				= 2,
	["INVTYPE_SHOULDER"]			= 3,
	["INVTYPE_BODY"] 				= 4,
	["INVTYPE_CHEST"]				= 5,
	["INVTYPE_ROBE"]				= 5,
	["INVTYPE_WAIST"]				= 6,
	["INVTYPE_LEGS"]				= 7,
	["INVTYPE_FEET"]				= 8,
	["INVTYPE_WRIST"]				= 9,
	["INVTYPE_HAND"]				= 10,
	["INVTYPE_FINGER"]				= {11,12},
	["INVTYPE_TRINKET"]				= {13,14},
	["INVTYPE_CLOAK"]				= 15,
	["INVTYPE_WEAPON"]				= {16,17},
	["INVTYPE_SHIELD"]				= 17,
	["INVTYPE_2HWEAPON"]			= 16,
	["INVTYPE_WEAPONMAINHAND"]		= 16,
	["INVTYPE_WEAPONOFFHAND"]	 	= 17,
	["INVTYPE_HOLDABLE"]			= 17,
	["INVTYPE_RANGED"]				= 18,
	["INVTYPE_THROWN"]				= 18,
	["INVTYPE_RANGEDRIGHT"]			= 18,
	["INVTYPE_RELIC"]				= 18,
	["INVTYPE_TABARD"]				= 19
}

local function print(msg)
    DEFAULT_CHAT_FRAME:AddMessage('RaidEquipCompare: '..msg, 1, 1, 1);
end
 
local cleared = true
local function OnTooltipCleared(self)
   cleared = true
end

local gear = {}
local queue = {}

local function addUnit(unit, slotId)
	if lre:HasGear(UnitGUID(unit)) then
		local items = lre:GetGear(UnitGUID(unit))
		
		local _, class = UnitClass(unit)
		local cc = RAID_CLASS_COLORS[class]
		
		if type(slotId)=="table" then
			for i, slot in ipairs(slotId) do
				local link = items[slot]
				--local link = GetInventoryItemLink(unit, slot)
				if link then
					local pname, plink, prarity, plevel, _, _, _, _, _, itemTexture, _ = GetItemInfo(link)
					local r, g, b, hex = GetItemQualityColor(prarity)
					GameTooltip:AddDoubleLine(UnitName(unit), "|T"..itemTexture..":0|t " .. pname .. " " .. plevel, cc.r, cc.g, cc.b, r, g, b)
				end
			end
		else
			local link = items[slotId] --GetInventoryItemLink(unit, slotId)
			if link then
				local pname, plink, prarity, plevel, _, _, _, _, _, itemTexture, _ = GetItemInfo(link)
				local r, g, b, hex = GetItemQualityColor(prarity)
				GameTooltip:AddDoubleLine(UnitName(unit), "|T"..itemTexture..":0|t " .. pname .. " " .. plevel, cc.r, cc.g, cc.b, r, g, b)
			else
				--print("no itemn!" .. UnitName(unit))
			end
		end
	else
		--print('no data for ' ..UnitName(unit))
	end
end

local function OnTooltipSetItem(self)
  local name, link = self:GetItem()
  if name and cleared then
	 local equippable = IsEquippableItem(link)
	 local item = link:match("Hitem:(%d+)")
	 item = tonumber(item)
	 if not equippable then
		-- Do nothing
	 else
		local itemName, itemLink, itemRarity, itemLevel, itemMinLevel, itemType, itemSubType, itemStackCount,
itemEquipLoc, itemTexture, itemSellPrice = GetItemInfo(item)

		local slotId = equipLocToSlotId[itemEquipLoc]
		if slotId then
			if IsInRaid() then
				--print("raid")
				for i = 1, GetNumGroupMembers() do
					addUnit('raid'..i, slotId)
				end
			elseif IsInGroup() then
				--print("group")
				addUnit('player', slotId) -- testing only
				for i = 1, GetNumGroupMembers() -1 do
					addUnit('party'..i, slotId)
				end
			else
				addUnit('player', slotId) -- testing only
			end
		end

		cleared = true
	 end
   end
end

function frame:OnEvent(event, ...)
	if self[event] then
		self[event] (self, ...)
	end
end

function frame:ADDON_LOADED(addon)
	if addon == "RaidEquipCompare" then
		lre:Enable()
		print('raidequipcompare loaded')
	end
end

GameTooltip:HookScript("OnTooltipCleared", OnTooltipCleared)
GameTooltip:HookScript("OnTooltipSetItem", OnTooltipSetItem)

frame:SetScript ("OnEvent", frame.OnEvent)
frame:RegisterEvent("ADDON_LOADED")
